@@ -150,7 +150,7 @@ static gint handle_canvas_click (GnomeCanvas *canvas, GdkEventButton *event, gpo
 GNOME_CLASS_BOILERPLATE (EogWrapList,
 			 eog_wrap_list,
 			 GnomeCanvas,
-			 GNOME_TYPE_CANVAS);
+			 GNOME_TYPE_CANVAS)
 
 /* Class initialization function for the abstract wrapped list view */
 static void
@@ -325,14 +325,11 @@ get_item_view_position (EogWrapList *wlist, GnomeCanvasItem *item)
 static void
 ensure_item_is_visible (EogWrapList *wlist, GnomeCanvasItem *item)
 {
-	EogWrapListPrivate *priv;
 	double x1, y1, x2, y2;
 	int width, height;
 	int ofsx, ofsy;
 	int scroll_x, scroll_y;
 
-	priv = wlist->priv;
-
 	width = GTK_WIDGET (wlist)->allocation.width;
 	height = GTK_WIDGET (wlist)->allocation.height;
 	gnome_canvas_get_scroll_offsets (GNOME_CANVAS (wlist), &ofsx, &ofsy);
@@ -600,76 +597,13 @@ eog_wrap_list_size_allocate (GtkWidget *widget, GtkAllocation *allocation)
 	request_update (wlist);
 }       
 
-static void 
-eog_wrap_list_select_up (EogWrapList *wlist)
-{
-	EogWrapListPrivate *priv;
-	GList *node;
-	GnomeCanvasItem *item;
-	int i;
-
-	g_return_if_fail (EOG_IS_WRAP_LIST (wlist));
-
-	priv = wlist->priv;
-
-	if (priv->n_selected_items != 1) return;
-
-	node = g_list_find (priv->view_order, priv->last_item_clicked);
-
-	for (i = 0; i < priv->n_cols && node != NULL; i++) {
-		node = node->prev;
-	}
-	if (node == NULL) return;
-
-	item = GNOME_CANVAS_ITEM (node->data);
-
-	set_select_status (wlist, EOG_COLLECTION_ITEM (priv->last_item_clicked), FALSE);
-	set_select_status (wlist, EOG_COLLECTION_ITEM (item), TRUE);
-	priv->last_item_clicked = item;
-
-	ensure_item_is_visible (wlist, item);
-
-	g_signal_emit (G_OBJECT (wlist), eog_wrap_list_signals [SELECTION_CHANGED], 0);
-}
-
-static void 
-eog_wrap_list_select_down (EogWrapList *wlist)
-{
-	EogWrapListPrivate *priv;
-	GList *node;
-	GnomeCanvasItem *item;
-	int i;
-
-	g_return_if_fail (EOG_IS_WRAP_LIST (wlist));
-
-	priv = wlist->priv;
-
-	if (priv->n_selected_items != 1) return;
-
-	node = g_list_find (priv->view_order, priv->last_item_clicked);
-
-	for (i = 0; i < priv->n_cols && node != NULL; i++) {
-		node = node->next;
-	}
-	if (node == NULL) return;
-
-	item = GNOME_CANVAS_ITEM (node->data);
-
-	set_select_status (wlist, EOG_COLLECTION_ITEM (priv->last_item_clicked), FALSE);
-	set_select_status (wlist, EOG_COLLECTION_ITEM (item), TRUE);
-	priv->last_item_clicked = item;
-
-	ensure_item_is_visible (wlist, item);
-
-	g_signal_emit (G_OBJECT (wlist), eog_wrap_list_signals [SELECTION_CHANGED], 0);
-}
-
 void 
-eog_wrap_list_select_left (EogWrapList *wlist)
+eog_wrap_list_select_single (EogWrapList *wlist, EogWrapListSelectChange change)
 {
 	EogWrapListPrivate *priv;
 	GList *node;
 	GnomeCanvasItem *item;
+	int i;
 
 	g_return_if_fail (EOG_IS_WRAP_LIST (wlist));
 
@@ -678,45 +612,44 @@ eog_wrap_list_select_left (EogWrapList *wlist)
 	if (priv->n_selected_items != 1) return;
 
 	node = g_list_find (priv->view_order, priv->last_item_clicked);
+
 	if (node == NULL) return;
 
-	node = node->prev;
-	if (node == NULL) {
-		node = g_list_last (priv->view_order);
-	}
-
-	item = GNOME_CANVAS_ITEM (node->data);
-
-	set_select_status (wlist, EOG_COLLECTION_ITEM (priv->last_item_clicked), FALSE);
-	set_select_status (wlist, EOG_COLLECTION_ITEM (item), TRUE);
-	priv->last_item_clicked = item;
-
-	ensure_item_is_visible (wlist, item);
-
-	g_signal_emit (G_OBJECT (wlist), eog_wrap_list_signals [SELECTION_CHANGED], 0);
-}
-
-void
-eog_wrap_list_select_right (EogWrapList *wlist)
-{
-	EogWrapListPrivate *priv;
-	GList *node;
-	GnomeCanvasItem *item;
-
-	g_return_if_fail (EOG_IS_WRAP_LIST (wlist));
-
-	priv = wlist->priv;
-
-	if (priv->n_selected_items != 1) return;
-
-	node = g_list_find (priv->view_order, priv->last_item_clicked);
-	if (node == NULL) return;
-
-	node = node->next;
-	if (node == NULL) {
+	switch (change) {
+	case EOG_WRAP_LIST_SELECT_UP:
+		for (i = 0; i < priv->n_cols && node != NULL; i++) {
+			node = node->prev;
+		}
+		break;
+	case EOG_WRAP_LIST_SELECT_DOWN:
+		for (i = 0; i < priv->n_cols && node != NULL; i++) {
+			node = node->next;
+		}
+		break;
+	case EOG_WRAP_LIST_SELECT_LEFT:
+		node = node->prev;
+		if (node == NULL) {
+			node = g_list_last (priv->view_order);
+		}
+		break;
+	case EOG_WRAP_LIST_SELECT_RIGHT:
+		node = node->next;
+		if (node == NULL) {
+			node = g_list_first (priv->view_order);
+		}
+		break;
+	case EOG_WRAP_LIST_SELECT_FIRST:
 		node = g_list_first (priv->view_order);
+		break;
+	case EOG_WRAP_LIST_SELECT_LAST:
+		node = g_list_last (priv->view_order);
+		break;
+	default:
+		g_assert_not_reached ();
 	}
 
+	if (node == NULL) return;
+
 	item = GNOME_CANVAS_ITEM (node->data);
 
 	set_select_status (wlist, EOG_COLLECTION_ITEM (priv->last_item_clicked), FALSE);
@@ -735,22 +668,22 @@ eog_wrap_list_key_press_cb (GtkWidget *widget, GdkEventKey *event)
 
 	switch (event->keyval) {
 	case GDK_Up:
-		eog_wrap_list_select_up (EOG_WRAP_LIST (widget));
+		eog_wrap_list_select_single (EOG_WRAP_LIST (widget), EOG_WRAP_LIST_SELECT_UP);
 		handled = TRUE;
 		break;
 
 	case GDK_Down:
-		eog_wrap_list_select_down (EOG_WRAP_LIST (widget));
+		eog_wrap_list_select_single (EOG_WRAP_LIST (widget), EOG_WRAP_LIST_SELECT_DOWN);
 		handled = TRUE;
 		break;
 
 	case GDK_Left:
-		eog_wrap_list_select_left (EOG_WRAP_LIST (widget));
+		eog_wrap_list_select_single (EOG_WRAP_LIST (widget), EOG_WRAP_LIST_SELECT_LEFT);
 		handled = TRUE;
 		break;
 
 	case GDK_Right:
-		eog_wrap_list_select_right (EOG_WRAP_LIST (widget));
+		eog_wrap_list_select_single (EOG_WRAP_LIST (widget), EOG_WRAP_LIST_SELECT_RIGHT);
 		handled = TRUE;
 		break;
 	};
@@ -838,7 +771,9 @@ create_items_from_model (EogWrapList *wlist, EogImageList *model)
 	EogIter *iter;
 	gboolean success;
 	EogImage *image;
+	EogCollectionItem *initial_item;
 	GList *it;
+	int pos;
 	
 	g_return_if_fail (EOG_IS_WRAP_LIST (wlist));
 	g_return_if_fail (EOG_IS_IMAGE_LIST (model));
@@ -867,8 +802,15 @@ create_items_from_model (EogWrapList *wlist, EogImageList *model)
 
 	if (priv->view_order != NULL) {
 		deselect_all (wlist);
-		if (set_select_status (wlist, EOG_COLLECTION_ITEM (priv->view_order->data), TRUE)) {
-			priv->last_item_clicked = GNOME_CANVAS_ITEM (priv->view_order->data);
+
+		pos = eog_image_list_get_initial_pos (priv->model);
+		if (pos == -1) return;
+
+		initial_item = g_list_nth_data (priv->view_order, pos);
+
+		if (set_select_status (wlist, EOG_COLLECTION_ITEM (initial_item), TRUE)) {
+			priv->last_item_clicked = GNOME_CANVAS_ITEM (initial_item);
+			ensure_item_is_visible (wlist, GNOME_CANVAS_ITEM (initial_item));
 			g_signal_emit (G_OBJECT (wlist), eog_wrap_list_signals [SELECTION_CHANGED], 0);
 		}
 	}
@@ -908,7 +850,6 @@ model_image_removed (EogImageList *model, int pos, gpointer data)
 	EogWrapListPrivate *priv;
 	GnomeCanvasItem *item;
 	GList *node;
-	gboolean selection_changed;
 
 	g_return_if_fail (EOG_IS_WRAP_LIST (data));
 
@@ -925,7 +866,7 @@ model_image_removed (EogImageList *model, int pos, gpointer data)
 		priv->last_item_clicked = NULL;
 	}
 	
-	selection_changed = set_select_status (wlist, EOG_COLLECTION_ITEM (item), FALSE);
+	set_select_status (wlist, EOG_COLLECTION_ITEM (item), FALSE);
 	priv->view_order = g_list_delete_link (priv->view_order, node);
 
 	/* delete object */
@@ -1060,7 +1001,6 @@ do_layout_check (EogWrapList *wlist)
 	unsigned int n_rows_new = 0;
 	unsigned int n_cols_new = 0;
 	gint cw;
-	gint ch;
 	
 	EogWrapListPrivate *priv;
 
@@ -1075,7 +1015,6 @@ do_layout_check (EogWrapList *wlist)
 
 	/* get canvas width */
 	cw = GTK_WIDGET (wlist)->allocation.width;
-	ch = GTK_WIDGET (wlist)->allocation.height;
 
 	/* calculate new number of  columns/rows */
 	n_cols_new = cw / (EOG_COLLECTION_ITEM_MAX_WIDTH + priv->col_spacing);
